# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.2.0

import datetime
import sys
import types
import typing
import uuid as _uuid
from builtins import property as _property

import winrt._winrt
import winrt.system
import winrt.windows.foundation as windows_foundation
import winrt.windows.media as windows_media

Self = typing.TypeVar('Self')

@typing.final
class SoundLevelBroker_Static(type):
    def add_sound_level_changed(cls, handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_sound_level_changed(cls, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    @_property
    def sound_level(cls) -> windows_media.SoundLevel: ...

@typing.final
class SoundLevelBroker(winrt.system.Object, metaclass=SoundLevelBroker_Static):
    pass

